@@ -203,7 +203,7 @@ face for highlighting the match."
   :group 'lui)
 
 (defcustom lui-buttons-list
-  `(("`\\([A-Za-z0-9+=*/-]+\\)'" 1
+  `(("`\\([A-Za-z0-9+=*/:-]+\\)'" 1
      lui-button-elisp-symbol 1)
     ("\\<debbugs[#:]\\([0-9]+\\)" 0
      "https://debbugs.gnu.org/cgi/bugreport.cgi?bug=%s" 1)
@@ -249,7 +249,7 @@ This can be one of the following values:
 
   A string
       This is used as the fill prefix
-  'variable
+  \\='variable
       The first sequence of non-whitespace characters in the
       output is used as an alignment, and the rest is filled with
       spaces.
@@ -291,15 +291,15 @@ This can be one of the following values:
 
   A number
       At this column of the first line of output
-  'right
+  \\='right
       At a column just right to `lui-fill-column'
-  'left
+  \\='left
       At the left side of the output. The output is thereby moved
       to the right.
-  'right-margin
+  \\='right-margin
       In the right margin.  You will need to set `right-margin-width'
       in all circe buffers.
-  'left-margin
+  \\='left-margin
       In the left margin.  You will need to set `left-margin-width'
       in all circe buffers.
   nil
@@ -314,7 +314,7 @@ This can be one of the following values:
 
 (defcustom lui-time-stamp-only-when-changed-p t
   "Non-nil if Lui should only add a time stamp when the time changes.
-If `lui-time-stamp-position' is 'left, this will still add the
+If `lui-time-stamp-position' is \\='left, this will still add the
 necessary whitespace."
   :type 'boolean
   :group 'lui)
@@ -712,7 +712,7 @@ Otherwise, we move to the next button."
 (defun lui-kill-to-beginning-of-line ()
   "Kill the input from point to the beginning of the input."
   (interactive)
-  (let* ((beg (point-at-bol))
+  (let* ((beg (line-beginning-position))
          (end (point))
          (str (buffer-substring beg end)))
     (delete-region beg end)
@@ -789,8 +789,8 @@ Otherwise, we move to the next button."
 
 (defun lui-fools ()
   "Propertize the current narrowing according to foolhardiness.
-That is, if any part of it has the text property 'lui-fool set,
-make the whole thing invisible."
+That is, if any part of it has the text property \\='lui-fool
+set, make the whole thing invisible."
   (when (text-property-any (point-min)
                            (point-max)
                            'lui-fool t)
@@ -1181,7 +1181,7 @@ function."
                        (goto-char (point-min))
                        (re-search-forward "\\s-" nil t)
                        (- (point)
-                          (point-at-bol)))))
+                          (line-beginning-position)))))
       (goto-char (point-min))
       (when (< right-end lui-fill-type)
         (insert (make-string (- lui-fill-type
@@ -1242,7 +1242,7 @@ If TEXT is specified, use that instead of formatting a new time stamp."
                 (not lui-time-stamp-last)
                 (not (string= ts lui-time-stamp-last)))
         (goto-char (point-min))
-        (goto-char (point-at-eol))
+        (goto-char (line-end-position))
         (let* ((curcol (current-column))
                (col (if (numberp lui-time-stamp-position)
                         lui-time-stamp-position
@@ -1290,7 +1290,7 @@ If TEXT is specified, use that instead of formatting a new time stamp."
                 (not (string= ts lui-time-stamp-last)))
         (goto-char (point-min))
         (when lui-fill-type
-          (goto-char (point-at-eol)))
+          (goto-char (line-end-position)))
         (let* ((ts (propertize ts 'face 'lui-time-stamp-face))
                (ts-margin (propertize
                            " "
@@ -1318,9 +1318,7 @@ DELETE."
                     (delete-and-extract-region beg end)
                   (buffer-substring beg end)))
         (inhibit-point-motion-hooks t)
-        (inhibit-read-only t)
-        ;; Emacs 24.4, 24.5
-        deactivate-mark)
+        (inhibit-read-only t))
     (with-temp-buffer
       (insert string)
       (let ((start (text-property-any (point-min)
