@@ -7,6 +7,7 @@
     (it "should have circe-server-buffer set in the mode hook"
       (let* ((csb-value nil)
              (circe-server-killed-confirmation nil)
+             (circe-network "test")
              (circe-chat-mode-hook (list
                                     (lambda ()
                                       (setq csb-value circe-server-buffer))))
@@ -62,12 +63,14 @@
       (setq server-buffer (generate-new-buffer "*Test Server*"))
       (set-buffer server-buffer)
       (circe-server-mode)
+      (setq circe-network "test")
       (setq proc (start-process "test" nil "cat")
             circe-server-process proc)
       (setq circe-server-killed-confirmation nil)
       (setq channel-buffer (circe-server-create-chat-buffer
                             "test" 'circe-channel-mode))
       (set-buffer channel-buffer)
+      (setq circe-network "test")
       (setq circe-channel-killed-confirmation nil)
       (spy-on 'circe-nick :and-return-value "mynick")
       (spy-on 'circe-channel-nicks :and-return-value '("testnick"))
